pub type GpuClusterConfig = GpuEuclideanClusterConfig;Expand description
Issue-compatible alias for GPU Euclidean cluster extraction config.
Aliased Type
pub struct GpuClusterConfig {
pub tolerance: f32,
pub min_cluster_size: usize,
pub max_cluster_size: usize,
pub max_neighbors: usize,
}Fields
tolerance: f32Maximum distance between neighboring points in the same cluster.
min_cluster_size: usizeMinimum number of points for a valid cluster.
max_cluster_size: usizeMaximum number of points allowed in a valid cluster.
max_neighbors: usizeMaximum radius neighbors retained per point from the GPU adjacency pass.